@@ -74,7 +74,7 @@
 #'   - See the Transformations section below for definitions of each transformation.
 #' * function: accept two equal-length numeric vectors of adjusted predictions (`hi` and `lo`) and returns a vector of contrasts of the same length, or a unique numeric value.
 #'   - See the Transformations section below for examples of valid functions.
-#' @param transform_post (experimental) A function applied to unit-level estimates and confidence intervals just before the function returns results.
+#' @param transform_post string or function. Transformation applied to unit-level estimates and confidence intervals just before the function returns results. Functions must accept a vector and return a vector of the same length. Support string shortcuts: "exp", "ln"
 #' @param by Compute group-wise average estimates. Valid inputs:
 #'   - Character vector of column names in `newdata` or in the data frame produced by calling the function without the `by` argument.
 #'   - Data frame with a `by` column of group labels, and merging columns shared by `newdata` or the data frame produced by calling the same function without the `by` argument.
@@ -113,6 +113,10 @@
 #' comparisons(mod, newdata = datagrid(am = 0, gear = tmp$gear))
 #' comparisons(mod, newdata = datagrid(am = unique, gear = max))
 #'
+#' m <- lm(mpg ~ hp + drat + factor(cyl) + factor(am), data = mtcars)
+#' comparisons(m, variables = "hp", newdata = datagrid(FUN_factor = unique, FUN_numeric = median))
+#'
+#'
 #' # Numeric contrasts
 #' mod <- lm(mpg ~ hp, data = mtcars)
 #' comparisons(mod, variables = list(hp = 1)) %>% tidy()
@@ -121,7 +125,7 @@
 #' comparisons(mod, variables = list(hp = "iqr")) %>% tidy()
 #' comparisons(mod, variables = list(hp = "sd")) %>% tidy()
 #' comparisons(mod, variables = list(hp = "minmax")) %>% tidy()
-#' 
+#'
 #' # using a function to specify a custom difference in one regressor
 #' dat <- mtcars
 #' dat$new_hp <- 49 * (dat$hp - min(dat$hp)) / (max(dat$hp) - min(dat$hp)) + 1
@@ -154,19 +158,19 @@
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = "wt = drat")
-#' 
+#'
 #' # same hypothesis test using row indices
 #' comparisons(
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = "b1 - b2 = 0")
-#' 
+#'
 #' # same hypothesis test using numeric vector of weights
 #' comparisons(
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = c(1, -1))
-#' 
+#'
 #' # two custom contrasts using a matrix of weights
 #' lc <- matrix(c(
 #'     1, -1,
@@ -176,20 +180,20 @@
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = lc)
-#' 
-#' 
+#'
+#'
 #' # `by` argument
 #' mod <- lm(mpg ~ hp * am * vs, data = mtcars)
 #' cmp <- comparisons(mod, variables = "hp", by = c("vs", "am"))
 #' summary(cmp)
-#' 
+#'
 #' library(nnet)
 #' mod <- multinom(factor(gear) ~ mpg + am * vs, data = mtcars, trace = FALSE)
 #' by <- data.frame(
 #'     group = c("3", "4", "5"),
 #'     by = c("3,4", "3,4", "5"))
 #' comparisons(mod, type = "probs", by = by)
-#' 
+#'
 #' @export
 comparisons <- function(model,
                         newdata = NULL,
@@ -206,15 +210,9 @@ comparisons <- function(model,
                         eps = NULL,
                         ...) {
 
+
     dots <- list(...)
 
-    transform_pre_label <- transform_post_label <- NULL
-    if (is.function(transform_pre)) {
-        transform_pre_label <- deparse(substitute(transform_pre))
-    }
-    if (is.function(transform_post)) {
-        transform_post_label <- deparse(substitute(transform_post))
-    }
 
     # marginaleffects()` **must** run its own sanity checks and hardcode valid arguments
     internal_call <- dots[["internal_call"]]
@@ -241,7 +239,6 @@ comparisons <- function(model,
             ...)
         cross <- sanitize_cross(cross, variables, model)
         type <- sanitize_type(model = model, type = type, calling_function = "marginaleffects")
-        checkmate::assert_function(transform_post, null.ok = TRUE)
 
     # internal call from `marginaleffects()`
     } else {
@@ -259,11 +256,19 @@ comparisons <- function(model,
     }
 
     conf_level <- sanitize_conf_level(conf_level, ...)
-    sanity_transform_pre(transform_pre)
     sanity_dots(model, ...)
     checkmate::assert_numeric(eps, len = 1, lower = 1e-10, null.ok = TRUE)
 
-    # used by `marginaleffects` to hard-code preference 
+    # transforms
+    sanity_transform_pre(transform_pre)
+    transform_pre_label <- transform_post_label <- NULL
+    if (is.function(transform_pre)) {
+        transform_pre_label <- deparse(substitute(transform_pre))
+    }
+    transform_post <- sanitize_transform_post(transform_post)
+
+
+    # used by `marginaleffects` to hard-code preference
     # deprecated as user-level arguments
     if ("contrast_factor" %in% names(dots)) {
         contrast_factor <- dots[["contrast_factor"]]
@@ -278,7 +283,7 @@ comparisons <- function(model,
         contrast_numeric <- 1
     }
 
-    marginalmeans <- isTRUE(checkmate::check_choice(newdata, choices = "marginalmeans")) 
+    marginalmeans <- isTRUE(checkmate::check_choice(newdata, choices = "marginalmeans"))
 
     # before sanitize_variables
     newdata <- sanitize_newdata(model = model, newdata = newdata, by = by)
@@ -312,7 +317,7 @@ comparisons <- function(model,
     if (is.character(vcov) &&
        # get_df() produces a weird warning on non lmerMod. We can skip them
        # because get_vcov() will produce an informative error later.
-       inherits(model, "lmerMod") && 
+       inherits(model, "lmerMod") &&
        (isTRUE(vcov == "satterthwaite") || isTRUE(vcov == "kenward-roger"))) {
         df <- insight::find_response(model)
         # predict.lmerTest requires the DV
@@ -322,7 +327,11 @@ comparisons <- function(model,
         # df_per_observation is an undocumented argument introduced in 0.18.4.7 to preserve backward incompatibility
         dof <- insight::get_df(model, type = vcov, data = newdata, df_per_observation = TRUE)
     } else {
-        dof <- NULL
+        if ("df" %in% names(dots)) {
+            dof <- dots[["df"]]
+        } else {
+            dof <- NULL
+        }
     }
 
     vcov_false <- isTRUE(vcov == FALSE)
@@ -399,7 +408,7 @@ comparisons <- function(model,
             tmp <- contrast_data$original[, ..idx, drop = FALSE]
             # contrast_data is duplicated to compute contrasts for different terms or pairs
             bycols <- intersect(colnames(tmp), colnames(mfx))
-            idx <- apply(tmp[, ..bycols], 1, paste, collapse = "|")
+            idx <- do.call(paste, c(tmp[, ..bycols], sep = "|"))
             tmp <- tmp[!duplicated(idx), , drop = FALSE]
             mfx <- merge(mfx, tmp, all.x = TRUE, by = bycols, sort = FALSE)
         # HACK: relies on NO sorting at ANY point
@@ -420,6 +429,7 @@ comparisons <- function(model,
         overwrite = FALSE,
         draws = draws,
         estimate = "comparison")
+        
 
 
     # group id: useful for merging, only if it's an internal call and not user-initiated
@@ -441,9 +451,7 @@ comparisons <- function(model,
     attr(mfx, "posterior_draws") <- draws
 
     # after draws attribute
-    if (!is.null(transform_post)) {
-        mfx <- backtransform(mfx, transform_post)
-    }
+    mfx <- backtransform(mfx, transform_post)
 
     # save as attribute and not column
     if (any(!is.na(mfx[["marginaleffects_wts_internal"]]))) {
@@ -475,11 +483,17 @@ comparisons <- function(model,
     attr(out, "vcov.type") <- vcov.type
     attr(out, "weights") <- marginaleffects_wts_internal
     attr(out, "transform_pre") <- transform_pre
-    attr(out, "transform_post") <- transform_post
+    attr(out, "transform_post") <- transform_post[[1]]
     attr(out, "transform_pre_label") <- transform_pre_label
-    attr(out, "transform_post_label") <- transform_post_label
+    attr(out, "transform_post_label") <- names(transform_post)[1]
     attr(out, "conf_level") <- conf_level
     attr(out, "by") <- by
+    attr(out, "call") <- match.call()
+
+    if (inherits(model, "brmsfit")) {
+        insight::check_if_installed("brms")
+        attr(out, "nchains") <- brms::nchains(model)
+    }
 
     if (!isTRUE(internal_call)) {
         if ("group" %in% names(out) && all(out$group == "main_marginaleffect")) {
