@@ -71,7 +71,6 @@ plot_cap <- function(model,
         } else if (identical(condition[[i]], "quartile")) {
             datplot[[v]] <- fun(datplot[[v]], c("Q1", "Q2", "Q3"))
         }
-
     }
 
     # colors and facets are categorical attributes
@@ -286,11 +285,15 @@ get_plot_newdata <- function(model, condition, effect = NULL) {
         }
     }
 
-    at_list[["model"]] = model
+    at_list[["model"]] <- model
 
     if (!is.null(effect)) {
+        # sometimes we use the same condition as effect (e.g., GAM vignette),
+        # but otherwise we don't want it at all
         if (isTRUE(checkmate::check_character(effect))) {
-            at_list[[effect]] <- NULL
+            if (!effect %in% names(condition)) {
+                at_list[[effect]] <- NULL
+            }
         } else {
             at_list[[names(effect)]] <- NULL
         }
