@@ -1,9 +1,15 @@
 #' Extract posterior draws from a `predictions`, `comparisons`, or `marginaleffects` object derived from Bayesian models.
 #'
 #' @param x An object produced by the `marginaleffects`, `comparisons`, or `predictions` functions
+#' @param shape string indicating the shape of the output format:
+#' * "long": long format data frame
+#' * "DxP": Matrix with draws as rows and parameters as columns
+#' * "PxD": Matrix with draws as rows and parameters as columns
 #' @return A data.frame with `drawid` and `draw` columns.
 #' @export
-posteriordraws <- function(x) {
+posteriordraws <- function(x, shape = "long") {
+
+    checkmate::assert_choice(shape, choices = c("long", "DxP", "PxD", "rvar"))
 
     # tidy.comparisons() sometimes already saves draws in a nice long format
     draws <- attr(x, "posterior_draws")
@@ -19,24 +25,48 @@ posteriordraws <- function(x) {
         stop('The number of parameters in the object does not match the number of parameters for which posterior draws are available.', call. = FALSE)
     }
 
-    draws <- data.table(draws)
-    setnames(draws, as.character(seq_len(ncol(draws))))
-
-    for (v in colnames(x)) {
-        draws[[v]] <- x[[v]]
+    if (shape %in% c("PxD", "DxP")) {
+        row.names(draws) <- paste0("b", seq_len(nrow(draws)))
+        colnames(draws) <- paste0("draw", seq_len(ncol(draws)))
     }
 
-    out <- melt(
-        draws,
-        id.vars = colnames(x),
-        variable.name = "drawid",
-        value.name = "draw")
+    if (shape == "PxD") {
+        return(draws)
+    }
+
+    if (shape == "DxP") {
+        return(t(draws))
+    }
+
+    if (shape == "rvar") {
+        insight::check_if_installed("posterior")
+        draws <- t(draws)
+        if (!is.null(attr(x, "nchains"))) {
+            x[["rvar"]] <- posterior::rvar(draws, nchains = attr(x, "nchains"))
+        } else {
+            x[["rvar"]] <- posterior::rvar(draws)
+        }
+        return(x)
+    }
+
+    if (shape == "long") {
+        draws <- data.table(draws)
+        setnames(draws, as.character(seq_len(ncol(draws))))
+        for (v in colnames(x)) {
+            draws[[v]] <- x[[v]]
+        }
+        out <- melt(
+            draws,
+            id.vars = colnames(x),
+            variable.name = "drawid",
+            value.name = "draw")
+        cols <- unique(c("drawid", "draw", "rowid", colnames(out)))
+        cols <- intersect(cols, colnames(out))
+        setcolorder(out, cols)
+        setDF(out)
+        return(out)
+    }
 
-    cols <- unique(c("drawid", "draw", "rowid", colnames(out)))
-    cols <- intersect(cols, colnames(out))
-    setcolorder(out, cols)
-    setDF(out)
-    return(out)
 }
 
 
