@@ -63,6 +63,7 @@ sanity_model_supported_class <- function(model) {
         "lmrob",
         "lmRob",
         "lm_robust",
+        # "logitr",
         "loess",
         c("lrm", "lm"),
         c("lrm", "rms", "glm"),
@@ -72,6 +73,8 @@ sanity_model_supported_class <- function(model) {
         "mlogit",
         c("multinom", "nnet"),
         c("negbin", "glm", "lm"),
+        c("ols", "rms", "lm"),
+        c("orm", "rms"),
         c("plm", "panelmodel"),
         "polr",
         "rlmerMod",
