@@ -56,13 +56,14 @@ tidy.comparisons <- function(x,
 
     dots <- list(...)
     conf_level <- sanitize_conf_level(conf_level, ...)
-    checkmate::assert_function(transform_avg, null.ok = TRUE)
 
+    # transformation
     transform_avg <- deprecation_arg(
         transform_avg,
         newname = "transform_avg",
         oldname = "transform_post",
         ...)
+    transform_avg <- sanitize_transform_post(transform_avg)
 
     x_dt <- data.table(x)
 
@@ -168,20 +169,26 @@ tidy.comparisons <- function(x,
         overwrite = FALSE,
         conf_level = conf_level,
         draws = draws,
-        estimate = "estimate")
+        estimate = "estimate",
+        ...)
 
     # remove terms with precise zero estimates. typically the case in
     # multi-equation models where some terms only affect one response
-    out <- out[out$estimate != 0, ]
+    idx <- out$estimate != 0
+    out <- out[idx, , drop = FALSE]
+    if (!is.null(draws)) {
+        draws <- draws[idx, , drop = FALSE]
+    }
+    if (exists("drawavg")) {
+        drawavg <- drawavg[idx, , drop = FALSE]
+    }
 
     # back transformation
-    if (!is.null(transform_avg)) {
-        if (!is.null(attr(x, "transform_post"))) {
-            msg <- "Estimates were transformed twice: once during the initial computation, and once more when summarizing the results in `tidy()` or `summary()`."
-            warning(insight::format_message(msg), call. = FALSE)
-        }
-        out <- backtransform(out, transform_avg)
+    if (!is.null(transform_avg) && !is.null(attr(x, "transform_post"))) {
+        msg <- "Estimates were transformed twice: once during the initial computation, and once more when summarizing the results in `tidy()` or `summary()`."
+        insight::format_warning(msg)
     }
+    out <- backtransform(out, transform_avg)
 
     # sort and subset columns
     cols <- c("type", "group", "term", "contrast",
@@ -196,10 +203,15 @@ tidy.comparisons <- function(x,
 
     attr(out, "conf_level") <- conf_level
     attr(out, "FUN") <- "mean"
+    attr(out, "nchains") <- attr(x, "nchains")
+    attr(out, "transform_post_label") <- attr(x, "transform_post_label")
+    attr(out, "transform_average_label") <- names(transform_avg)[1]
 
     if (exists("drawavg")) {
         class(drawavg) <- c("posterior_draws", class(drawavg))
         attr(out, "posterior_draws") <- drawavg
+    } else {
+        attr(out, "posterior_draws") <- draws
     }
 
     if (exists("J_mean")) {
