@@ -12,6 +12,9 @@ conflicted::conflict_prefer(name = "kidney", winner = "brms", quiet = TRUE)
 conflicted::conflict_prefer(name = "ngrps", winner = "brms", quiet = TRUE)
 conflicted::conflict_prefer(name = "lizards", winner = "aod", quiet = TRUE)
 conflicted::conflict_prefer(name = "rats", winner = "aod", quiet = TRUE)
+conflicted::conflict_prefer(name = "mad", winner = "stats", quiet = TRUE)
+conflicted::conflict_prefer(name = "sd", winner = "stats", quiet = TRUE)
+conflicted::conflict_prefer(name = "var", winner = "stats", quiet = TRUE)
 
 ON_CRAN <- !identical(Sys.getenv("R_NOT_CRAN"), "true")
 ON_GH <- identical(Sys.getenv("R_GH"), "true")
