@@ -11,11 +11,14 @@ options("marginaleffects_credible_interval" = "hdi")
 requiet("brms")
 requiet("emmeans")
 requiet("broom")
+requiet("posterior")
 requiet("brmsmargins")
 tol <- 0.0001
 tol_se <- 0.001
 
 
+
+
 # download models
 brms_numeric <- marginaleffects:::modelarchive_model("brms_numeric")
 brms_numeric2 <- marginaleffects:::modelarchive_model("brms_numeric2")
@@ -627,3 +630,26 @@ bm <- brmsmargins(
 expect_equivalent(cmp$estimate, bm$Mdn, tolerance = .05)
 expect_equivalent(cmp$conf.low, bm$LL, tolerance = .05)
 expect_equivalent(cmp$conf.high, bm$UL, tolerance = .05)
+
+
+
+# posteriordraws(shape = )
+cmp <- comparisons(brms_numeric2)
+tid <- tidy(cmp)
+pd <- posteriordraws(tid, shape = "DxP")
+hyp <- brms::hypothesis(pd, "b1 - b2 > 0")
+expect_inherits(hyp, "brmshypothesis")
+
+
+
+# posterior::rvar
+cmp <- comparisons(brms_numeric2)
+tid <- tidy(cmp)
+rv <- posteriordraws(tid, "rvar")
+expect_equivalent(nrow(rv), 2)
+expect_inherits(rv$rvar[[1]], "rvar")
+
+
+# Issue #546
+cmp <- comparisons(brms_numeric2, newdata = datagrid())
+expect_false(anyNA(cmp$am))
\ No newline at end of file
